aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/menus.h
diff options
context:
space:
mode:
authorStig Bjørlykke <stig@bjorlykke.org>2011-05-20 11:30:51 +0000
committerStig Bjørlykke <stig@bjorlykke.org>2011-05-20 11:30:51 +0000
commit2c1ede3dce95aa9b10fe63947bf50752d874e7ff (patch)
treebe6d27bd2a592d816f72ab860ee5868d6ffb2660 /gtk/menus.h
parentbcd55c173bfdccee7248e34218115935b2cdddba (diff)
Include the profile name in the Delete item in the profiles popup.
Fixed creating a new profile from the popup without setting a create from. Removed some unneeded ep_strdup_printf. svn path=/trunk/; revision=37324
Diffstat (limited to 'gtk/menus.h')
-rw-r--r--gtk/menus.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/gtk/menus.h b/gtk/menus.h
index c8630db77e..85e2ada4df 100644
--- a/gtk/menus.h
+++ b/gtk/menus.h
@@ -127,8 +127,11 @@ void menus_set_column_align_default (gboolean right_justify);
/* Update the packet list heading menu to indicate if column can be resolved. */
void menus_set_column_resolved (gboolean resolved, gboolean can_resolve);
-/* Fetch the statusbar profiles submenu */
-extern GtkWidget *menus_get_profiles_menu (void);
+/* Fetch the statusbar profiles delete submenu */
+extern GtkWidget *menus_get_profiles_delete_menu (void);
+
+/* Fetch the statusbar profiles change submenu */
+extern GtkWidget *menus_get_profiles_change_menu (void);
/* Enable or disable menu items based on whether a tree row is selected
and and on whether a "Match Selected" can be done. */